@@ -140,8 +140,10 @@ def rk_within_day_large_down_fps(
 
 def rk_comparison_by_price(
     start: str,
+    end: str,
     price_area: str,
     ref_price: int,
+    ref_dt: str = None,
     *,
     access_token: str = None,
 ):
@@ -149,14 +151,21 @@ def rk_comparison_by_price(
     Method to get probability for rk within day in comparison to provided price
     Parameters:
         start: Start timestamp
+        end: End timestamp
         price_area: Price area
         ref_price: Reference price to compare against
+        ref_dt:
+            Reference time for predictions.
+            Defaults to None.
+            If None, the latest available is used.
         access_token: Access token
     """
     query = {
         "start": start,
+        "end": end,
         "price_area": price_area,
         "ref_price": ref_price,
+        "ref_dt": ref_dt,
     }
     data = make_api_request(
         f"{get_api_base_url_v2()}/rk_within_day/price_comparison/by_price",
@@ -168,8 +177,10 @@ def rk_comparison_by_price(
 
 def rk_comparison_by_probability(
     start: str,
+    end: str,
     price_area: str,
     ref_probability: int,
+    ref_dt: str = None,
     *,
     access_token: str = None,
 ):
@@ -177,14 +188,21 @@ def rk_comparison_by_probability(
     Method to get probability for rk within day in comparison to provided price
     Parameters:
         start: Start timestamp
+        end: End timestamp
         price_area: Price area
         ref_probability: Reference probability to compare against
+        ref_dt:
+            Reference time for predictions.
+            Defaults to None.
+            If None, the latest available is used.
         access_token: Access token
     """
     query = {
         "start": start,
+        "end": end,
         "price_area": price_area,
         "ref_probability": ref_probability,
+        "ref_dt": ref_dt,
     }
     data = make_api_request(
         f"{get_api_base_url_v2()}/rk_within_day/price_comparison/by_probability",
